import { __decorate } from "tslib";
import { bind, isString } from './babel.dependencies';
export class Config {
    constructor(app) {
        /**
         * @public
         */
        this.name = '@roots/bud-babel';
        /**
         * @public
         */
        this.plugins = {};
        /**
         * @public
         */
        this.presets = {};
        this._app = () => app;
    }
    /**
     * @public
     */
    get app() {
        return this._app();
    }
    normalizeEntry(c) {
        return isString(c)
            ? [c, {}]
            : c;
    }
    setPlugin(plugin) {
        plugin = this.normalizeEntry(plugin);
        this.plugins = Object.assign(Object.assign({}, this.plugins), { [plugin[0]]: plugin });
        return this;
    }
    setPlugins(plugins) {
        plugins.map(this.setPlugin);
        return this;
    }
    setPreset(preset) {
        preset = this.normalizeEntry(preset);
        this.presets = Object.assign(Object.assign({}, this.presets), { [preset[0]]: preset });
        return this;
    }
    setPresets(presets) {
        presets.map(this.setPreset);
        return this;
    }
    unsetPreset(preset) {
        !this.presets[preset]
            ? this.app.error(`${preset} not found`)
            : delete this.presets[preset];
        return this;
    }
    unsetPlugin(plugin) {
        !this.plugins[plugin]
            ? this.app.error(`${plugin} not found`)
            : delete this.plugins[plugin];
        return this;
    }
    setPluginOptions(plugin, options) {
        this.plugins[plugin] = [this.plugins[plugin][0], options];
        return this;
    }
    setPresetOptions(preset, options) {
        this.presets[preset] = [this.presets[preset][0], options];
        return this;
    }
}
__decorate([
    bind
], Config.prototype, "normalizeEntry", null);
__decorate([
    bind
], Config.prototype, "setPlugin", null);
__decorate([
    bind
], Config.prototype, "setPlugins", null);
__decorate([
    bind
], Config.prototype, "setPreset", null);
__decorate([
    bind
], Config.prototype, "setPresets", null);
__decorate([
    bind
], Config.prototype, "unsetPreset", null);
__decorate([
    bind
], Config.prototype, "unsetPlugin", null);
__decorate([
    bind
], Config.prototype, "setPluginOptions", null);
__decorate([
    bind
], Config.prototype, "setPresetOptions", null);
//# sourceMappingURL=babel.config.js.map